#### JEAutoControl.Mouse
*  Contains classes for control mouse 
#### JEAutoControl.Keyboard
*   Contains classes for keyboard classes
#### Detail
* Alpha version 0.0.5
* Run on windows
* pypi : https://pypi.org/project/JEAutoControl/
* Github : https://github.com/JE-Chen/Python_JEAutoControl

##### you can use this lib to control windows mouse and keyboard